
/*
*The following Stata code was created using Stata version 15. 
The code (when accomgenerates the main tables  the manuscript "Decomposing Changes in Establishment
Level Emissions with Entry and Exit", by J. Scott Holladay and Lawrence D. LaPlue
published in the Canadian Journal of Economics. 
The industry-level data used in the following analysis can be downloaded from either the journal (data appendix) 
or the author's website (lawrencelaplue.com/research). 
*/

*Variable definitions and notes (with generating code provided below to clarify in some cases):
foreach v in var{
/*
Note: When the establishment values were collapse, two prefixes were added to the variable labels:
Annual values that were averaged in the industry-collapse are labeled with a "(mean)" prefix, 
indstry values that were added are labeled with a "(sum)" prefix
 

sales_real: is establishment sales weighted by NBER price-indices, aggregated to it's primary SIC4

PoundsPT_RSEI: are establishments emissions (type depends on the file being analyzed) taken from RSEI and aggreagted to the SIC4 level

ann_EI2: is equal to total emissions divided by total output (sales_real), by year. 

Two groups (A and B) are identified by entry and exit. 
Establishments in group "A" in each period are survivors not exiting in that period
Establishments in group "B" in each period are survivors not exiting in that period
Each of the "industry" values are given by equations (4) and (5) in the paper (equation 5 is only applied to surviving firms in each period)
But, rather than aggregating establishment values to the annual values, by group (survivors, entrants, exiters), 
they have been aggregated first within their SIC4 industry. The following code continues
the aggregation to the annual values in the pubished version of the analysis.

mean_EI_A and mean_EI_B: are unweighted annual average emissions intensity of each group, A or B,and 
are used in the Dynamic Olley-Pakes decomposition step given in equation (5)). 
	egen double mean_EI_A=mean(EI) if survive_A==1,by(year) //Survivor group A
	egen double mean_EI_B=mean(EI) if survive_B==1,by(year) //Survivor group B

wt_enter: market-share of entering establishments (where "wt" is given by: gen double wt=sales_real/ann_sales_real
and ann_sales_real =total(sales_real),by(year)
 	egen double wt_exit=total(wt)      if exit==1,by(year)

	wt_exit: market-share of exiting establishments
	egen double wt_enter=total(wt)     if enter==1,by(year)

EI_sic_estab: establishment-market-share weighted average Emissions Intensity, for each SIC4
	egen double EI_sic_estab=total(wt_sic*EI),by(year sic)

*/
}


********************************************************************************
********************************************************************************
*Begin analysis

set more off
pause off 
cd "<<ENTER YOUR PATH HERE>>"  //Replace the text in paraentheses (including the arrows with the path to the dataset on your local machine

foreach poln in air_VOC air_PM10 air_SO2 air_Haz water_Haz_on_and_off_site water_Haz_onsite{
********************************************************************************
*Begin with industry data/results
*Data files have been partially aggregated from the NETS establishment level to SIC4 industry level
*A seperate file has been created for each pollutant analyzed

*For each pollutant, the following code first decomposes the traditional "scale", "composition", and aggregate (industry) "technique" effects. 
*The code then further decomposese the industry technique effect into "reallocation", "selection", and "process" effects. 
*Finally, the results for all of the pollutants are gathered together and exported to excel to create and format the tables and figures. 

use "aggregated_industry\industry_decomp_`poln'.dta",clear
********************************************************************************
*1. Scale,  Composition, Aggregate Technique 
*Keep in mind: When adding up the percentage-change:
*a. The "Composition" effect already incorporates the "Scale" effect -- Do NOT double add them. 
*b. The "Reallocation" and "Technique" effects are decomposing the Aggregate "Technique" effect 
*	(i.e. aggregate emissions intensity) and, as such, already incorporate the "Composition" effect -- Do NOT double add them. 
foreach var in SCT{

xtset sic year
sort sic year


*Composition effect:
*Generate the base year emissions intensity by SIC (hold fixed for Composition effect)
gen double base_EI_sic_estab= EI_sic_estab if year==1990
forval y = 1/12{
by sic: replace base_EI_sic_estab=L`y'.base_EI_sic_estab if base_EI_sic_estab==.
}

gen composition=sales_real*base_EI_sic



*NOTE: After collapse, the "Composition" variable is really the Scale + Composition effect!
collapse (sum) sales_real  PoundsPT composition industry* (mean) ann* wt* mean* EI* ,by(year)  


gen EI=PoundsPT/sales_real

format %14.0g PoundsPT sales_real composition
}
*																				

*Administrative
	*After aggregating industry data (via 'collapse') to annual:
	replace industry_cov_EI_B=. if year==1990										//Missing since data start in 1990
	replace industry_EI_survive_B=. if year==1990									//Missing since data start in 1990

	*Rename to drop industry pre-fix
	rename (industry_cov_EI_A industry_cov_EI_B ///
			industry_EI_survive_A industry_EI_survive_B ///
			industry_EI_exit industry_EI_enter) ///
			(cov_EI_A cov_EI_B ///
			EI_survive_A EI_survive_B ///
			EI_exit EI_enter)

	gen ident=1
	xtset ident year


	
********************************************************************************
********************************************************************************
*2.1 Aggregate decomposition (after aggregating industry results) : Process, Selection, and Reallocation
*See M&P Appendix -- this scale factor places all annual changes calculations into percentage-change terms
gen double scale = (ann_EI+L1.ann_EI)/2

********************************************************************************
*Decomposition (into percent, with use of 'scale') following M&P
gen double change_enter = wt_enter*(EI_enter- EI_survive_B)/scale        		//Negative if entrants in period 2 have lower EI than survors in period 2
gen double change_exit  = L1.wt_exit*(L1.EI_survive_A-L1.EI_exit)/scale 		//Negative if fims exiting (from period 1 to period 2) have higher emissions intensity than the surviving firms.
gen double change_surv  = (EI_survive_B-L1.EI_survive_A)/scale 					//Negative if the survivors in period 2 have lower average EI than survivors in period 1 


gen double change_total = change_surv+ change_enter+ change_exit
********************************************************************************
********************************************************************************
*2.2 Additional Decomposition of Survivors: Within and Across (building on M&P application of 
*Mean and Covariance
*Weight / scale
gen double cov_tilde_A = cov_EI_A/EI_survive_A
gen double cov_tilde_B = cov_EI_B/EI_survive_B
gen double mean_cov_tilde_s = (cov_tilde_B + L1.cov_tilde_A)/2					

gen double mean_s = (EI_survive_B+L1.EI_survive_A)/2							


*Change Within (process)
gen double change_s_within = (mean_EI_B - L1.mean_EI_A)/((1-mean_cov_tilde_s)*scale)
*Change Across (reallocation)
gen double change_s_across = ((cov_tilde_B - L1.cov_tilde_A)*mean_s)/((1-mean_cov_tilde_s)*scale)

keep year change* EI  PoundsPT composition sales_real

gen double reallocation=change_s_across											//NOTE: 0.01=1%
gen double selection=change_enter+change_exit
gen double process=change_s_within
gen double technique=reallocation+selection+process
label var reallocation "=change_s_across"
label var selection "=change_enter+change_exit"
label var process "=change_s_within"
label var technique "=total=reallocation+process+selection"

order year	change_enter	change_exit	change_surv	change_total	change_s_within	change_s_across	///
		reallocation	selection	process	technique	///
		PoundsPT_RSEI	sales_real	composition	EI

export excel using "4_channel_decomp_CJE_final.xlsx", sheet("`poln'") sheetreplace firstrow(variables)
}
*
